@@ -22,9 +22,10 @@ class CodeMapper:
         mapping = self.mapping
 
         for item in self.items:
-            for code, value in item.codes.items():
-                mapping[code] = mapping.get(code) or []
-                mapping[code].append((value, item))
+            for code, values in item.codes.items():
+                for value in values:
+                    mapping[code] = mapping.get(code) or []
+                    mapping[code].append((value, item))
 
     def get_by_codes(self, codes: Sequence):
         r = self.registry
