@@ -39,9 +39,27 @@ def make_merge_division_code(seeker, code: Any):
     return seeker.name, code
 
 
-def merge_divisions(items: Sequence[DivisionItem], change_path: bool = True):
+def update_existing_codes(codes, existing_codes):
+    codes_sets = {}
+
+    for code, value in codes:
+        codes_sets[code] = codes_sets.get(code) or set(existing_codes.get(code) or [])
+        codes_sets[code].add(value)
+
+    for code, items in codes_sets.items():
+        existing_codes[code] = list(items)
+
+    return existing_codes
+
+
+def merge_divisions(
+    items: Sequence[DivisionItem],
+    change_path: bool = True,
+    change_level: bool = True,
+    change_types: bool = True
+):
     d = MergeCommiter(Division, update_fields=(
-        ('name', 'types', 'level', 'synonyms',)
+        ('name', 'types', 'codes', 'level', 'synonyms',)
         +
         (('parent_id', 'path') if change_path else ())
     ))
@@ -50,21 +68,21 @@ def merge_divisions(items: Sequence[DivisionItem], change_path: bool = True):
     divisions = find_by_codes(get_code_seeker_registry(), items)
 
     for item in items:
-        eqs = divisions.get_one(get_item_codes(item))
+        item_codes = get_item_codes(item)
+        eqs = divisions.get_one(item_codes)
         path = [divisions.get_one([code]) for code in item['path']]
 
         if None in path and (change_path or eqs is None):
             d.fail(item, code='path_failure', path=path)
             continue
 
-        path = [x.id for x in path]
-        code, code_value = item['code']
+        path = [(x.id if x else x) for x in path]
         parent_id = path[-1] if len(path) > 0 else None
 
         if eqs is None:
             d.create(Division(
                 name = item['name'],
-                codes = {code: [code_value]},
+                codes = update_existing_codes(item_codes, {}),
                 types = item['types'],
                 level = item['level'],
                 path = LtreeValue(path),
@@ -72,12 +90,14 @@ def merge_divisions(items: Sequence[DivisionItem], change_path: bool = True):
             ))
         else:
             eqs.path = LtreeValue(path + [eqs.id])
-            eqs.codes[code] = set(eqs.codes.get(code) or [])
-            eqs.codes[code].add(code_value)
-            eqs.codes[code] = list(eqs.codes[code])
+            eqs.codes = update_existing_codes(item_codes, eqs.codes or {})
             eqs.parent_id = parent_id
-            eqs.level = item['level']
-            eqs.types = list(set((eqs.types or []) + item['types']))
+
+            if change_level:
+                eqs.level = item['level']
+
+            if change_types:
+                eqs.types = list(set((eqs.types or []) + item['types']))
 
             inject_synonyms(eqs, item['name'])
 
