@@ -1,15 +1,18 @@
 
-from typing import Any, List, Optional, Tuple, TypeVar, TypedDict
+from typing import Any, List, Optional, Tuple, TypedDict
 
 from wcd_geo_db.const import DivisionLevel, DivisionType
 
 
-__all__ = 'DivisionItem', 'DivisionTranslationItem',
+__all__ = 'CodesItem', 'DivisionItem', 'DivisionTranslationItem',
 
 
-class DivisionItem(TypedDict):
+class CodesItem(TypedDict):
     code: Tuple[str, Any]
     codes: List[Tuple[str, Any]]
+
+
+class DivisionItem(CodesItem, TypedDict):
     path: List[Tuple[str, Any]]
     name: Optional[str]
     types: List[DivisionType]
